function [mu, sigma_2] = estimate_gaussian(X)

% [mu, sigma_2] = estimate_gaussian(X)
% 
% This function estimates the parameters of a Gaussian distribution using 
% the input data stored in the matrix "X" (dimensions rows: observations, 
% cols: features). The sample mean and sample variance are estimated for
% each feature.
% 
% INPUTS:
% X         - input data matrix (rows: observations, cols: features)
%
% OUTPUTS:
% mu        - sample mean ([n, 1] vector; n = number of features)
% sigma_2   - sample variance ([n, 1] vector; n = number of features)
%
%
%
% --
% ing. Zoltn Gal
% xgalaz00@stud.feec.vutbr.cz       
% 
% Department of Telecommunications
% Faculty of Electrical Engineering and Communication
% Brno University of Technology

% Get the sizes of the input data
[m, n] = size(X);

% Compute the sample mean/s
mu = (1.0/(m - 1)).*sum(X);
mu = mu(:);

% Compute the sample variation/s
sigma_2 = (1.0/(m - 1)).*sum((X - repmat(mu', m, 1)).^2);
sigma_2 = sigma_2(:);