function p = multivariate_gaussian(X, mu, sigma_2)

% p = multivariate_gaussian(X, mu, sigma_2)
%
% This function estimates the probability density function for the multi-
% variate gaussian distribution using the input data stored in the matrix
% "X" (dimensions rows: observations, cols: features), and estimates of
% the sample mean and variance for X. 
%
% If the input sample variance (sigma_2) is a matrix, it is treated as the 
% covariance matrix. If Sigma2 is a vector, it is treated as the values of 
% the variances in each dimension (a diagonal covariance matrix).
%
% INPUTS:
% X         - input data matrix (rows: observations, cols: features)
% mu        - sample mean ([n, 1] vector; n = number of features)
% sigma_2   - sample variance ([n, 1] vector; n = number of features)
%
% OUTPUTS:
% p         - output probability density function estimate
%
%
%
% --
% ing. Zoltn Gal
% xgalaz00@stud.feec.vutbr.cz       
% 
% Department of Telecommunications
% Faculty of Electrical Engineering and Communication
% Brno University of Technology

%% Check the dimensions of the covariance matrix
if (size(sigma_2, 2) == 1) || (size(sigma_2, 1) == 1)
    sigma_2 = diag(sigma_2);
end

%% Compute the probability density function
X = bsxfun(@minus, X, mu(:)');
p = (2.0*pi)^(-length(mu)/2.0)*det(sigma_2)^(-0.5) * ...
    exp(-0.5*sum(bsxfun(@times, X*pinv(sigma_2), X), 2));